@@ -1,7 +1,8 @@
 """Module containing a preprocessor that converts outputs in the notebook from
 one format to another.
-"""
 
+Converts all of the outputs in a notebook from one format to another.
+"""
 # Copyright (c) Jupyter Development Team.
 # Distributed under the terms of the Modified BSD License.
 
@@ -26,6 +27,7 @@ class ConvertFiguresPreprocessor(Preprocessor):
         super().__init__(**kw)
 
     def convert_figure(self, data_format, data):
+        """Convert the figure."""
         raise NotImplementedError()
 
     def preprocess_cell(self, cell, resources, cell_index):
