@@ -1,6 +1,8 @@
 """Module containing a preprocessor that executes the code cells
 and updates outputs"""
+import typing as t
 
+from jupyter_client.manager import KernelManager
 from nbclient import NotebookClient
 from nbclient import execute as _execute
 
@@ -15,6 +17,7 @@ from .base import Preprocessor
 
 
 def executenb(*args, **kwargs):
+    """DEPRECATED."""
     from warnings import warn
 
     warn(
@@ -34,7 +37,11 @@ class ExecutePreprocessor(Preprocessor, NotebookClient):
     """
 
     def __init__(self, **kw):
+        """Initialize the preprocessor."""
         nb = kw.get("nb")
+        if nb is None:
+            nb = NotebookNode()
+        kw.setdefault("kernel_manager_class", KernelManager)
         Preprocessor.__init__(self, nb=nb, **kw)
         NotebookClient.__init__(self, nb, **kw)
 
@@ -42,7 +49,9 @@ class ExecutePreprocessor(Preprocessor, NotebookClient):
         if resources or not hasattr(self, "resources"):
             self.resources = resources
 
-    def preprocess(self, nb: NotebookNode, resources=None, km=None):
+    def preprocess(
+        self, nb: NotebookNode, resources: t.Any = None, km: t.Optional[KernelManager] = None
+    ) -> t.Tuple[NotebookNode, dict]:
         """
         Preprocess notebook executing each code cell.
 
@@ -83,7 +92,9 @@ class ExecutePreprocessor(Preprocessor, NotebookClient):
         self._check_assign_resources(resources)
 
         with self.setup_kernel():
+            assert self.kc
             info_msg = self.wait_for_reply(self.kc.kernel_info())
+            assert info_msg
             self.nb.metadata["language_info"] = info_msg["content"]["language_info"]
             for index, cell in enumerate(self.nb.cells):
                 self.preprocess_cell(cell, resources, index)
